Struct LegacyTokenLimit
pub struct LegacyTokenLimit {
pub token: Address,
pub amount: Uint<256, 4>,
}Expand description
Legacy token spending limit structure used before T3.
struct LegacyTokenLimit { address token; uint256 amount; }Fields
token: Addressamount: Uint<256, 4>Trait Implementations
impl Clone for LegacyTokenLimit
impl Clone for LegacyTokenLimit
fn clone(&self) -> LegacyTokenLimit
fn clone(&self) -> LegacyTokenLimit
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for LegacyTokenLimit
impl Debug for LegacyTokenLimit
impl<'de> Deserialize<'de> for LegacyTokenLimit
impl<'de> Deserialize<'de> for LegacyTokenLimit
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LegacyTokenLimit, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LegacyTokenLimit, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for LegacyTokenLimit
impl EventTopic for LegacyTokenLimit
impl EventTopic for LegacyTokenLimit
fn topic_preimage_length(
rust: &<LegacyTokenLimit as SolType>::RustType,
) -> usize
fn topic_preimage_length( rust: &<LegacyTokenLimit as SolType>::RustType, ) -> usize
fn encode_topic_preimage(
rust: &<LegacyTokenLimit as SolType>::RustType,
out: &mut Vec<u8>,
)
fn encode_topic_preimage( rust: &<LegacyTokenLimit as SolType>::RustType, out: &mut Vec<u8>, )
encode_topic][EventTopic::encode_topic]. Read morefn encode_topic(rust: &<LegacyTokenLimit as SolType>::RustType) -> WordToken
fn encode_topic(rust: &<LegacyTokenLimit as SolType>::RustType) -> WordToken
impl PartialEq for LegacyTokenLimit
impl PartialEq for LegacyTokenLimit
fn eq(&self, other: &LegacyTokenLimit) -> bool
fn eq(&self, other: &LegacyTokenLimit) -> bool
self and other values to be equal, and is used by ==.impl Serialize for LegacyTokenLimit
impl Serialize for LegacyTokenLimit
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolStruct for LegacyTokenLimit
impl SolStruct for LegacyTokenLimit
fn eip712_root_type() -> Cow<'static, str>
fn eip712_root_type() -> Cow<'static, str>
encodeType string.fn eip712_components() -> Vec<Cow<'static, str>>
fn eip712_components() -> Vec<Cow<'static, str>>
encodeType string. These are the types of the struct’s fields,
and should not include the root type.fn eip712_encode_type() -> Cow<'static, str>
fn eip712_encode_type() -> Cow<'static, str>
fn eip712_encode_data(&self) -> Vec<u8> ⓘ
fn eip712_encode_data(&self) -> Vec<u8> ⓘ
encodeData.fn eip712_type_hash(&self) -> FixedBytes<32>
fn eip712_type_hash(&self) -> FixedBytes<32>
typeHash
for this struct. Read morefn eip712_hash_struct(&self) -> FixedBytes<32>
fn eip712_hash_struct(&self) -> FixedBytes<32>
hashStruct for this value.fn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
fn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
impl SolType for LegacyTokenLimit
impl SolType for LegacyTokenLimit
const SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
const SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
const ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
const ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
const PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
const PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
type RustType = LegacyTokenLimit
type RustType = LegacyTokenLimit
type Token<'a> = <(Address, Uint<256>) as SolType>::Token<'a>
type Token<'a> = <(Address, Uint<256>) as SolType>::Token<'a>
fn valid_token(token: &<LegacyTokenLimit as SolType>::Token<'_>) -> bool
fn valid_token(token: &<LegacyTokenLimit as SolType>::Token<'_>) -> bool
true if the given token can be detokenized with this type.fn detokenize(
token: <LegacyTokenLimit as SolType>::Token<'_>,
) -> <LegacyTokenLimit as SolType>::RustType
fn detokenize( token: <LegacyTokenLimit as SolType>::Token<'_>, ) -> <LegacyTokenLimit as SolType>::RustType
fn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn type_check(token: &Self::Token<'_>) -> Result<(), Error>
fn type_check(token: &Self::Token<'_>) -> Result<(), Error>
fn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
fn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
fn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
fn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
encodeData rules, and hash it
if necessary. Read morefn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_params_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_params_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_sequence<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_sequence<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_sequence_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_sequence_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
impl SolValue for LegacyTokenLimit
impl SolValue for LegacyTokenLimit
type SolType = LegacyTokenLimit
type SolType = LegacyTokenLimit
fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Selfwhere
Self: From<<Self::SolType as SolType>::RustType>,
fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Selfwhere
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn eip712_data_word(&self) -> FixedBytes<32>
fn eip712_data_word(&self) -> FixedBytes<32>
encodeData rules, and hash it
if necessary. Read morefn abi_encode_packed_to(&self, out: &mut Vec<u8>)
fn abi_encode_packed_to(&self, out: &mut Vec<u8>)
fn abi_encode_sequence(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_sequence(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_params(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_params(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_decode(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_decode(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
impl StructuralPartialEq for LegacyTokenLimit